==> java-compiler-impl-193.6015.39-sources.jar: com/intellij/compiler/backwardRefs/view/DirtyScopeTestInfo.java <==
/*
 * Copyright 2000-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.compiler.backwardRefs.view;

import com.intellij.openapi.module.Module;
import com.intellij.openapi.vfs.VirtualFile;
import com.intellij.psi.search.GlobalSearchScope;
import org.jetbrains.annotations.NotNull;

public class DirtyScopeTestInfo {
  private final Module[] myDirtyModules;
  private final Module[] myDirtyUnsavedModules;
  private final VirtualFile[] myExcludedFiles;
  private final GlobalSearchScope myDirtyScope;

  public DirtyScopeTestInfo(Module[] dirtyModules,
                            Module[] dirtyUnsavedModules,
                            VirtualFile[] files,
                            GlobalSearchScope dirtyScope) {

    myDirtyModules = dirtyModules;
    myDirtyUnsavedModules = dirtyUnsavedModules;
    myExcludedFiles = files;
    myDirtyScope = dirtyScope;
  }

  @NotNull
  Module[] getDirtyModules() {
    return myDirtyModules;
  }

  @NotNull
  Module[] getDirtyUnsavedModules() {
    return myDirtyUnsavedModules;
  }

  @NotNull
  VirtualFile[] getExcludedFiles() {
    return myExcludedFiles;
  }

  @NotNull
  GlobalSearchScope getDirtyScope() { return myDirtyScope; }
}

==> java-compiler-impl-202.8194.7-sources.jar: com/intellij/compiler/backwardRefs/view/DirtyScopeTestInfo.java <==
/*
 * Copyright 2000-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.compiler.backwardRefs.view;

import com.intellij.openapi.module.Module;
import com.intellij.openapi.vfs.VirtualFile;
import com.intellij.psi.search.GlobalSearchScope;
import org.jetbrains.annotations.NotNull;

public class DirtyScopeTestInfo {
  private final Module[] myDirtyModules;
  private final Module[] myDirtyUnsavedModules;
  private final VirtualFile[] myExcludedFiles;
  private final GlobalSearchScope myDirtyScope;

  public DirtyScopeTestInfo(Module[] dirtyModules,
                            Module[] dirtyUnsavedModules,
                            VirtualFile[] files,
                            GlobalSearchScope dirtyScope) {

    myDirtyModules = dirtyModules;
    myDirtyUnsavedModules = dirtyUnsavedModules;
    myExcludedFiles = files;
    myDirtyScope = dirtyScope;
  }

  Module @NotNull [] getDirtyModules() {
    return myDirtyModules;
  }

  Module @NotNull [] getDirtyUnsavedModules() {
    return myDirtyUnsavedModules;
  }

  VirtualFile @NotNull [] getExcludedFiles() {
    return myExcludedFiles;
  }

  @NotNull
  GlobalSearchScope getDirtyScope() { return myDirtyScope; }
}
